# Kad2GP

Инструмент, берущий данные с сайта http://pkk.rosreestr.ru/ по кадастровому номеру участка и преобращующий их в готовый для обсустройсства план в программе [Garden Planner](http://smallblueprinter.com/garden/) с корректными размерами участка.

## Зависимости

* [rosreestr2coord](https://github.com/rendrom/rosreestr2coord)

## Установка

Установка через пакетный менеджер

```bash
pip install kad2gp
```

Установка девелоперской версии

```bash
git clone https://github.com/TonSilver/kad2gp
cd ./kad2gp
python setup.py install
```


